Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(571)

Unified Diff: src/compiler/js-native-context-specialization.h

Issue 2703133003: [turbofan] Unify NodeProperties::InferReceiverMaps. (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/compiler/js-inlining.cc ('k') | src/compiler/js-native-context-specialization.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compiler/js-native-context-specialization.h
diff --git a/src/compiler/js-native-context-specialization.h b/src/compiler/js-native-context-specialization.h
index 289619c5dbf4e63648e0ded4403021971525c152..005a66d37e483ec09fa4b92cc222b7ace89562c1 100644
--- a/src/compiler/js-native-context-specialization.h
+++ b/src/compiler/js-native-context-specialization.h
@@ -147,10 +147,12 @@ class JSNativeContextSpecialization final : public AdvancedReducer {
FeedbackNexus const& nexus,
MapHandleList* receiver_maps);
- // Try to infer a map for the given {receiver} at the current {effect}.
- // If a map is returned then you can be sure that the {receiver} definitely
- // has the returned map at this point in the program (identified by {effect}).
- MaybeHandle<Map> InferReceiverMap(Node* receiver, Node* effect);
+ // Try to infer maps for the given {receiver} at the current {effect}.
+ // If maps are returned then you can be sure that the {receiver} definitely
+ // has one of the returned maps at this point in the program (identified
+ // by {effect}).
+ bool InferReceiverMaps(Node* receiver, Node* effect,
+ MapHandleList* receiver_maps);
// Try to infer a root map for the {receiver} independent of the current
// program location.
MaybeHandle<Map> InferReceiverRootMap(Node* receiver);
« no previous file with comments | « src/compiler/js-inlining.cc ('k') | src/compiler/js-native-context-specialization.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698